# Fairo Metrics 

Collection of metrics that are pre-certified and tested for use in the Fairo AI Governance System. 
This package can be used standalone, or with full/partial back-end integration with the Fairo Test Case Management System (part of Fairo Premium).

The metrics in this package are designed to help test AI for fairness and quality. 
They have been curated for use in our system and the list is by no means final. 
Metrics can be requested by opening an issue on GitHub, reaching out on Intercom, or sending a message on Slack. 
